==> haskell-servant-client-0.20.3.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-3cSKCNc4AY71kmho20NOrF
key:                  servant-client-0.20.3.0-3cSKCNc4AY71kmho20NOrF
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  b71e86024270f046b7eaaa1a1dc4bb88
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-3cSKCNc4AY71kmho20NOrF
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-3rmvGvyaabxFxCJ9oJ0aDx
    http-media-0.8.1.1-8uDE1LVwBQG8pjkw28yYI5
    http-types-0.12.4-AxSTuELtXS8Ebx20Rd9Bgd
    kan-extensions-5.2.7-3flWIGbWHOp6j8j1JHZRv0
    monad-control-1.0.3.1-JhIUlMwO22REEhKxuYKLpf mtl-2.2.2
    semigroupoids-6.0.1-Dyiulc79AG72hQ04hyBGLr
    servant-0.20.3.0-EuzmrbVYAb29vCD4LJtCFZ
    servant-client-core-0.20.3.0-1FhCPrHHm4UKKrPbVfspD1 stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-BAx0nW43BWmJb9h46BesnM

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20.3.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-K2rKaslCamFGbN8q5i8XQZ
key:                  servant-client-0.20.3.0-K2rKaslCamFGbN8q5i8XQZ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  185e337832a1b9fee616e816d7fdddfb
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-K2rKaslCamFGbN8q5i8XQZ
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-2IAKaL0RajRLDWsZpaLmo9
    http-media-0.8.1.1-dduLhl1Bxp9vxCFPCMX8i
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    kan-extensions-5.2.7-5TNadmEhpvk84V1hzzcFfj
    monad-control-1.0.3.1-GYvvySxcDDsKr3A3afhWG mtl-2.2.2
    semigroupoids-6.0.1-KCNtGml05AHAYKR3WNsoxY
    servant-0.20.3.0-Akz8MaXqLz2CTV2vjy3My1
    servant-client-core-0.20.3.0-KVEcq0b3ncEJKWo2TlJzCv stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-7u55LZmMXS5CMak7FcNNxB

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
